﻿<#
    Init script for TSBackground.exe
    Company: Onevinn AB
    Name: TSBackgroundInit.ps1
    Author: Johan Schrewelius
    Date: 2019-07-17
    Version: 1.3
#>


[CmdletBinding()]
Param(
 [Parameter(Mandatory=$True,Position=1)]
  [string]$NumberOfStepsInErrorGroup = "0",
  [string]$DateTimeFormat = "yyyy-MM-dd HH:mm:ss"
  )

function Get-IP {

    (gwmi -Class 'Win32_NetworkAdapterConfiguration' -Filter "IPEnabled = 1") | foreach {
        
        $_.IPAddress |% {
            if($_ -ne $null) {
                if($_.IndexOf('.') -gt 0 -and !$_.StartsWith("169.254") -and $_ -ne "0.0.0.0") {
                    $ip = $_
                   
                }
            }
        }
    }

    $ip 
}

function Get-MacInfo {

    $nic = (gwmi -Class 'Win32_NetworkAdapter' -Filter "NetConnectionStatus = 2")
    $nic.MACAddress -join ','
}

try {
    Start-Sleep -Seconds 5
    $tsenv = New-Object -COMObject Microsoft.SMS.TSEnvironment

    $OSDComputerName = $tsenv.Value("OSDComputerName")
    $SMSTSMachineName = $tsenv.Value("_SMSTSMachineName")
    $Mac = Get-MacInfo
    $IP = Get-IP

    $IsInPe = $tsenv.Value("_SMSTSInWinPE").ToUpper().Equals("TRUE")
    $st = $tsenv.Value("TSBStartTimeTicks")
    $TSBIsRunning = (gwmi -Namespace 'Root\Cimv2' -Query "Select * From Win32_Process Where Name = 'TSBackground.exe'")
    $tsenv.Value("TSBNumberOfStepsInErrorGroup") = "$NumberOfStepsInErrorGroup"

    if ($IsInPe -and !$TSBIsRunning) {
        Start-Process -FilePath "X:\sms\PKG\SMS10000\TSBackground\TSBackground.exe"
    }
    elseif (!$st) {
        $tsenv.Value("TSBStartTime") = [System.DateTime]::Now.ToString("$DateTimeFormat")
        $tsenv.Value("TSBStartTimeUTC") = [System.DateTime]::Now.ToUniversalTime().ToString("$DateTimeFormat")
        $tsenv.Value("TSBStartTimeTicks") = [System.DateTime]::Now.ToUniversalTime().Ticks
    }

    $tsenv.Value("TSBConnectionInfo") = "52032916-965B-480E-B2D0-C16FE6BCB4DA;$($OSDComputerName);$($SMSTSMachineName);$($Mac);$($IP);"
    exit 0
}
catch {}

exit 1

# SIG # Begin signature block
# MIIawQYJKoZIhvcNAQcCoIIasjCCGq4CAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCCkyYGPax7RaSwQ
# f+PdKbl5mCcnGpSgdJrSB8MT67h4JqCCCUIwggSZMIIDgaADAgECAhBxoLc2ld2x
# r8I7K5oY7lTLMA0GCSqGSIb3DQEBCwUAMIGpMQswCQYDVQQGEwJVUzEVMBMGA1UE
# ChMMdGhhd3RlLCBJbmMuMSgwJgYDVQQLEx9DZXJ0aWZpY2F0aW9uIFNlcnZpY2Vz
# IERpdmlzaW9uMTgwNgYDVQQLEy8oYykgMjAwNiB0aGF3dGUsIEluYy4gLSBGb3Ig
# YXV0aG9yaXplZCB1c2Ugb25seTEfMB0GA1UEAxMWdGhhd3RlIFByaW1hcnkgUm9v
# dCBDQTAeFw0xMzEyMTAwMDAwMDBaFw0yMzEyMDkyMzU5NTlaMEwxCzAJBgNVBAYT
# AlVTMRUwEwYDVQQKEwx0aGF3dGUsIEluYy4xJjAkBgNVBAMTHXRoYXd0ZSBTSEEy
# NTYgQ29kZSBTaWduaW5nIENBMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC
# AQEAm1UCTBcF6dBmw/wordPA/u/g6X7UHvaqG5FG/fUW7ZgHU/q6hxt9nh8BJ6u5
# 0mfKtxAlU/TjvpuQuO0jXELvZCVY5YgiGr71x671voqxERGTGiKpdGnBdLZoh6eD
# MPlk8bHjOD701sH8Ev5zVxc1V4rdUI0D+GbNynaDE8jXDnEd5GPJuhf40bnkiNIs
# KMghIA1BtwviL8KA5oh7U2zDRGOBf2hHjCsqz1v0jElhummF/WsAeAUmaRMwgDhO
# 8VpVycVQ1qo4iUdDXP5Nc6VJxZNp/neWmq/zjA5XujPZDsZC0wN3xLs5rZH58/eW
# XDpkpu0nV8HoQPNT8r4pNP5f+QIDAQABo4IBFzCCARMwLwYIKwYBBQUHAQEEIzAh
# MB8GCCsGAQUFBzABhhNodHRwOi8vdDIuc3ltY2IuY29tMBIGA1UdEwEB/wQIMAYB
# Af8CAQAwMgYDVR0fBCswKTAnoCWgI4YhaHR0cDovL3QxLnN5bWNiLmNvbS9UaGF3
# dGVQQ0EuY3JsMB0GA1UdJQQWMBQGCCsGAQUFBwMCBggrBgEFBQcDAzAOBgNVHQ8B
# Af8EBAMCAQYwKQYDVR0RBCIwIKQeMBwxGjAYBgNVBAMTEVN5bWFudGVjUEtJLTEt
# NTY4MB0GA1UdDgQWBBRXhptUuL6mKYrk9sLiExiJhc3ctzAfBgNVHSMEGDAWgBR7
# W0XPr87Lev0xkhpqtvNG61dIUDANBgkqhkiG9w0BAQsFAAOCAQEAJDv116A2E8dD
# /vAJh2jRmDFuEuQ/Hh+We2tMHoeei8Vso7EMe1CS1YGcsY8sKbfu+ZEFuY5B8Sz2
# 0FktmOC56oABR0CVuD2dA715uzW2rZxMJ/ZnRRDJxbyHTlV70oe73dww78bUbMyZ
# NW0c4GDTzWiPKVlLiZYIRsmO/HVPxdwJzE4ni0TNB7ysBOC1M6WHn/TdcwyR6hKB
# b+N18B61k2xEF9U+l8m9ByxWdx+F3Ubov94sgZSj9+W3p8E3n3XKVXdNXjYpyoXY
# RUFyV3XAeVv6NBAGbWQgQrc6yB8dRmQCX8ZHvvDEOihU2vYeT5qiGUOkb0n4/F5C
# ICiEi0cgbjCCBKEwggOJoAMCAQICEFfnOlE8mSYbF2fhqOEGyAgwDQYJKoZIhvcN
# AQELBQAwTDELMAkGA1UEBhMCVVMxFTATBgNVBAoTDHRoYXd0ZSwgSW5jLjEmMCQG
# A1UEAxMddGhhd3RlIFNIQTI1NiBDb2RlIFNpZ25pbmcgQ0EwHhcNMTcxMDAyMDAw
# MDAwWhcNMjAxMDAxMjM1OTU5WjBfMQswCQYDVQQGEwJTRTERMA8GA1UEBwwIR290
# ZWJvcmcxEzARBgNVBAoMCk9uZXZpbm4gQUIxEzARBgNVBAsMCk9uZXZpbm4gQUIx
# EzARBgNVBAMMCk9uZXZpbm4gQUIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEK
# AoIBAQCSDK/UTbE2cqiqgHdtLu9Qo67I9J3GqMRqVDihq5DmCSIFyMCWgMabS1qT
# X3ue4h7k0CRDaxmtePuLGcW6g1EFjJGNP2qtt+uILK7+Z3xRiLbWU6ba5Mx3PTkj
# vHqA0W3lV9skn4SZMOr7N6yljEfvKNcDDdaEIJyS7PW/3JkaiUWxEZyplLneXf87
# PLFIf8IvQq2DoMuVKw4UqPW/lSRTjScZS3NQyFLrxID0hZz/KxgLZhlIF9zwfrWp
# UtSLeG+a7SEIkfmbXJBWcG3wFoY3pzxgeN8A+Q7nL2iIT/SQK55Iat/OEO4BA+W4
# KPlYXClyW0TPLjoZi2wfXU0arjxzAgMBAAGjggFqMIIBZjAJBgNVHRMEAjAAMB8G
# A1UdIwQYMBaAFFeGm1S4vqYpiuT2wuITGImFzdy3MB0GA1UdDgQWBBTa2WrrvKai
# 8z7/QLZmtAGBEseWOzArBgNVHR8EJDAiMCCgHqAchhpodHRwOi8vdGwuc3ltY2Iu
# Y29tL3RsLmNybDAOBgNVHQ8BAf8EBAMCB4AwEwYDVR0lBAwwCgYIKwYBBQUHAwMw
# bgYDVR0gBGcwZTBjBgZngQwBBAEwWTAmBggrBgEFBQcCARYaaHR0cHM6Ly93d3cu
# dGhhd3RlLmNvbS9jcHMwLwYIKwYBBQUHAgIwIwwhaHR0cHM6Ly93d3cudGhhd3Rl
# LmNvbS9yZXBvc2l0b3J5MFcGCCsGAQUFBwEBBEswSTAfBggrBgEFBQcwAYYTaHR0
# cDovL3RsLnN5bWNkLmNvbTAmBggrBgEFBQcwAoYaaHR0cDovL3RsLnN5bWNiLmNv
# bS90bC5jcnQwDQYJKoZIhvcNAQELBQADggEBAAguh4y/xs04GNUq+jdQ6WhA1+et
# PfeNwm1H2GP1U85ADXcFdJxhwz4mnNUTYdnrRJ3SPxPjhj2WJz4z6VX853x2egzz
# Xfclz9VfG0MLo9zC4q60MusZgq/eyYJvk+LKuWhHtI++5yrfy3Q0284bTtXeVHhc
# ya/5d1L8rqv1yd4e6t2FDu+/hqVPea1UzuVm4s9sfG/2EU44EiAhAEHrpIfZX3Yx
# gVlR071SGso8HagLoKTIrCm3QJ+3IYK+Nc4Qt8bhfzsAzPWuLAkNZJfF9yCqFM3F
# ++3Btt0/rfbJ2sN5FH6aNYQezuXbUyjQ3YEfYmhnfdp8qpODKWA1AzCEAlsxghDV
# MIIQ0QIBATBgMEwxCzAJBgNVBAYTAlVTMRUwEwYDVQQKEwx0aGF3dGUsIEluYy4x
# JjAkBgNVBAMTHXRoYXd0ZSBTSEEyNTYgQ29kZSBTaWduaW5nIENBAhBX5zpRPJkm
# Gxdn4ajhBsgIMA0GCWCGSAFlAwQCAQUAoHwwEAYKKwYBBAGCNwIBDDECMAAwGQYJ
# KoZIhvcNAQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisGAQQB
# gjcCARUwLwYJKoZIhvcNAQkEMSIEIExTkAdko1nZQCqWl+vyH7xr10eeNqp8Rzc7
# YYEw/rRFMA0GCSqGSIb3DQEBAQUABIIBAFHsx8rWYuaW7TlYYcThQwH6akntue8o
# O2YIBZFZ4GGzNyM+gghQv/C3q6QumN7+QWn+KU57aPleZMPMEaKxnxpwAzZmJo3h
# vY8/ZSVZ8HkcJfWONsJCm6o/e3vq2x2ybKMBVBut0NGv/YwP5k6bxqf+pul3NXWO
# 247UUQ/BF2ID5U2cPTPY240GCYE3yvhXQT/DqdIt0zrQXkeaaeK5dtoCHB69hZHl
# Pfv/BghReQD/9eiTxElepT6oQsNAzIFq79JO6WUPikDn4+dJwp8+5cQvWc7Odl7l
# XOL9VzE6OWBl4yMZUCiuE9HRx/pbkt/1UClP9vaCI5ea3aaqxuxQ7OOhgg7IMIIO
# xAYKKwYBBAGCNwMDATGCDrQwgg6wBgkqhkiG9w0BBwKggg6hMIIOnQIBAzEPMA0G
# CWCGSAFlAwQCAQUAMHcGCyqGSIb3DQEJEAEEoGgEZjBkAgEBBglghkgBhv1sBwEw
# MTANBglghkgBZQMEAgEFAAQgka8LW8uHMi+gkODCwN+drC0glER1oKfs3GMUICpu
# 2h0CEEQu9sLyE0Ra94ZsUbZssUoYDzIwMTkwNzE3MjE1MTAyWqCCC7swggaCMIIF
# aqADAgECAhAJwPxGyARCE7VZi68oT05BMA0GCSqGSIb3DQEBCwUAMHIxCzAJBgNV
# BAYTAlVTMRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdp
# Y2VydC5jb20xMTAvBgNVBAMTKERpZ2lDZXJ0IFNIQTIgQXNzdXJlZCBJRCBUaW1l
# c3RhbXBpbmcgQ0EwHhcNMTcwMTA0MDAwMDAwWhcNMjgwMTE4MDAwMDAwWjBMMQsw
# CQYDVQQGEwJVUzERMA8GA1UEChMIRGlnaUNlcnQxKjAoBgNVBAMTIURpZ2lDZXJ0
# IFNIQTIgVGltZXN0YW1wIFJlc3BvbmRlcjCCASIwDQYJKoZIhvcNAQEBBQADggEP
# ADCCAQoCggEBAJ6VmGo0O3MbqH78x74paYnHaCZGXz2NYnOHgaOhnPC3WyQ3WpLU
# 9FnXdonk3NUn8NVmvArutCsxZ6xYxUqRWStFHgkB1mSzWe6NZk37I17MEA0Limfv
# Uq6gCJDCUvf1qLVumyx7nee1Pvt4zTJQGL9AtUyMu1f0oE8RRWxCQrnlr9bf9Kd8
# CmiWD9JfKVfO+x0y//QRoRMi+xLL79dT0uuXy6KsGx2dWCFRgsLC3uorPywihNBD
# 7Ds7P0fE9lbcRTeYtGt0tVmveFdpyA8JAnjd2FPBmdtgxJ3qrq/gfoZKXKlYYahe
# dIoBKGhyTqeGnbUCUodwZkjTju+BJMzc2GUCAwEAAaOCAzgwggM0MA4GA1UdDwEB
# /wQEAwIHgDAMBgNVHRMBAf8EAjAAMBYGA1UdJQEB/wQMMAoGCCsGAQUFBwMIMIIB
# vwYDVR0gBIIBtjCCAbIwggGhBglghkgBhv1sBwEwggGSMCgGCCsGAQUFBwIBFhxo
# dHRwczovL3d3dy5kaWdpY2VydC5jb20vQ1BTMIIBZAYIKwYBBQUHAgIwggFWHoIB
# UgBBAG4AeQAgAHUAcwBlACAAbwBmACAAdABoAGkAcwAgAEMAZQByAHQAaQBmAGkA
# YwBhAHQAZQAgAGMAbwBuAHMAdABpAHQAdQB0AGUAcwAgAGEAYwBjAGUAcAB0AGEA
# bgBjAGUAIABvAGYAIAB0AGgAZQAgAEQAaQBnAGkAQwBlAHIAdAAgAEMAUAAvAEMA
# UABTACAAYQBuAGQAIAB0AGgAZQAgAFIAZQBsAHkAaQBuAGcAIABQAGEAcgB0AHkA
# IABBAGcAcgBlAGUAbQBlAG4AdAAgAHcAaABpAGMAaAAgAGwAaQBtAGkAdAAgAGwA
# aQBhAGIAaQBsAGkAdAB5ACAAYQBuAGQAIABhAHIAZQAgAGkAbgBjAG8AcgBwAG8A
# cgBhAHQAZQBkACAAaABlAHIAZQBpAG4AIABiAHkAIAByAGUAZgBlAHIAZQBuAGMA
# ZQAuMAsGCWCGSAGG/WwDFTAfBgNVHSMEGDAWgBT0tuEgHf4prtLkYaWyoiWyyBc1
# bjAdBgNVHQ4EFgQU4acySu4BISh9VNXyB5JutAcPPYcwcQYDVR0fBGowaDAyoDCg
# LoYsaHR0cDovL2NybDMuZGlnaWNlcnQuY29tL3NoYTItYXNzdXJlZC10cy5jcmww
# MqAwoC6GLGh0dHA6Ly9jcmw0LmRpZ2ljZXJ0LmNvbS9zaGEyLWFzc3VyZWQtdHMu
# Y3JsMIGFBggrBgEFBQcBAQR5MHcwJAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRp
# Z2ljZXJ0LmNvbTBPBggrBgEFBQcwAoZDaHR0cDovL2NhY2VydHMuZGlnaWNlcnQu
# Y29tL0RpZ2lDZXJ0U0hBMkFzc3VyZWRJRFRpbWVzdGFtcGluZ0NBLmNydDANBgkq
# hkiG9w0BAQsFAAOCAQEAHvBBgjKu7fG0NRPcUMLVl64iIp0ODq8z00z9fL9vARGn
# lGUiXMYiociJUmuajHNc2V4/Mt4WYEyLNv0xmQq9wYS3jR3viSYTBVbzR81HW62E
# sjivaiO1ReMeiDJGgNK3ppki/cF4z/WL2AyMBQnuROaA1W1wzJ9THifdKkje2pNl
# rW5lo5mnwkAOc8xYT49FKOW8nIjmKM5gXS0lXYtzLqUNW1Hamk7/UAWJKNryeLvS
# WHiNRKesOgCReGmJZATTXZbfKr/5pUwsk//mit2CrPHSs6KGmsFViVZqRz/61jOV
# QzWJBXhaOmnaIrgEQ9NvaDU2ehQ+RemYZIYPEwwmSjCCBTEwggQZoAMCAQICEAqh
# JdbWMht+QeQF2jaXwhUwDQYJKoZIhvcNAQELBQAwZTELMAkGA1UEBhMCVVMxFTAT
# BgNVBAoTDERpZ2lDZXJ0IEluYzEZMBcGA1UECxMQd3d3LmRpZ2ljZXJ0LmNvbTEk
# MCIGA1UEAxMbRGlnaUNlcnQgQXNzdXJlZCBJRCBSb290IENBMB4XDTE2MDEwNzEy
# MDAwMFoXDTMxMDEwNzEyMDAwMFowcjELMAkGA1UEBhMCVVMxFTATBgNVBAoTDERp
# Z2lDZXJ0IEluYzEZMBcGA1UECxMQd3d3LmRpZ2ljZXJ0LmNvbTExMC8GA1UEAxMo
# RGlnaUNlcnQgU0hBMiBBc3N1cmVkIElEIFRpbWVzdGFtcGluZyBDQTCCASIwDQYJ
# KoZIhvcNAQEBBQADggEPADCCAQoCggEBAL3QMu5LzY9/3am6gpnFOVQoV7YjSsQO
# B0UzURB90Pl9TWh+57ag9I2ziOSXv2MhkJi/E7xX08PhfgjWahQAOPcuHjvuzKb2
# Mln+X2U/4Jvr40ZHBhpVfgsnfsCi9aDg3iI/Dv9+lfvzo7oiPhisEeTwmQNtO4V8
# CdPuXciaC1TjqAlxa+DPIhAPdc9xck4Krd9AOly3UeGheRTGTSQjMF287Dxgaqwv
# B8z98OpH2YhQXv1mblZhJymJhFHmgudGUP2UKiyn5HU+upgPhH+fMRTWrdXyZMt7
# HgXQhBlyF/EXBu89zdZN7wZC/aJTKk+FHcQdPK/P2qwQ9d2srOlW/5MCAwEAAaOC
# Ac4wggHKMB0GA1UdDgQWBBT0tuEgHf4prtLkYaWyoiWyyBc1bjAfBgNVHSMEGDAW
# gBRF66Kv9JLLgjEtUYunpyGd823IDzASBgNVHRMBAf8ECDAGAQH/AgEAMA4GA1Ud
# DwEB/wQEAwIBhjATBgNVHSUEDDAKBggrBgEFBQcDCDB5BggrBgEFBQcBAQRtMGsw
# JAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNvbTBDBggrBgEFBQcw
# AoY3aHR0cDovL2NhY2VydHMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0QXNzdXJlZElE
# Um9vdENBLmNydDCBgQYDVR0fBHoweDA6oDigNoY0aHR0cDovL2NybDQuZGlnaWNl
# cnQuY29tL0RpZ2lDZXJ0QXNzdXJlZElEUm9vdENBLmNybDA6oDigNoY0aHR0cDov
# L2NybDMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0QXNzdXJlZElEUm9vdENBLmNybDBQ
# BgNVHSAESTBHMDgGCmCGSAGG/WwAAgQwKjAoBggrBgEFBQcCARYcaHR0cHM6Ly93
# d3cuZGlnaWNlcnQuY29tL0NQUzALBglghkgBhv1sBwEwDQYJKoZIhvcNAQELBQAD
# ggEBAHGVEulRh1Zpze/d2nyqY3qzeM8GN0CE70uEv8rPAwL9xafDDiBCLK938ysf
# DCFaKrcFNB1qrpn4J6JmvwmqYN92pDqTD/iy0dh8GWLoXoIlHsS6HHssIeLWWywU
# NUMEaLLbdQLgcseY1jxk5R9IEBhfiThhTWJGJIdjjJFSLK8pieV4H9YLFKWA1xJH
# cLN11ZOFk362kmf7U2GJqPVrlsD0WGkNfMgBsbkodbeZY4UijGHKeZR+WfyMD+Nv
# tQEmtmyl7odRIeRYYJu6DC0rbaLEfrvEJStHAgh8Sa4TtuF8QkIoxhhWz0E0tmZd
# tnR79VYzIi8iNrJLokqV2PWmjlIxggJNMIICSQIBATCBhjByMQswCQYDVQQGEwJV
# UzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMRkwFwYDVQQLExB3d3cuZGlnaWNlcnQu
# Y29tMTEwLwYDVQQDEyhEaWdpQ2VydCBTSEEyIEFzc3VyZWQgSUQgVGltZXN0YW1w
# aW5nIENBAhAJwPxGyARCE7VZi68oT05BMA0GCWCGSAFlAwQCAQUAoIGYMBoGCSqG
# SIb3DQEJAzENBgsqhkiG9w0BCRABBDAcBgkqhkiG9w0BCQUxDxcNMTkwNzE3MjE1
# MTAyWjArBgsqhkiG9w0BCRACDDEcMBowGDAWBBRAAZFHXJiJHeuhBK9HCRtettTL
# yzAvBgkqhkiG9w0BCQQxIgQg2RpKsIk8RCiWgJIj3h1hA2V2+/7oLjcmwC5TeqxY
# hYgwDQYJKoZIhvcNAQEBBQAEggEAS7AYieVfroAQt/S4OeSjVoyyYcixGZKH2kUe
# hHC5YGU5rg5H2WioYviEARvy0ptC+QbUxvUjkGsdZqtZtg3izWNC0uhoBvH+YE4W
# 6Lse/jktI36MPrOTrl+pMj9qfLHDhMS251ESka7zlm6YmNQ0sHt8lru0lLCMf/XR
# 3gIDzco4FRLdoZ5J4lNmt/T6LFNn8eApvAzgsrKMy+BLkrbssQUgU10CYi4rkZs8
# 72gNlkzSrGAzR0ZUt65fZK5XhWer1P+W/Iwl7RyWRur5x1XNCuCLSgNwmNjElUeB
# 2ZT3cCsrwWZxjQq+LeeLe1OfrPdhgu2+Vi/SGbHgEYA608OigA==
# SIG # End signature block
